@@ -29,9 +29,9 @@ def main():
 
     parser = argparse.ArgumentParser(description='Create a config file for martin vector tile server')
 
-    # parser.add_argument('-s', '--database-schema',
-    #                         help='A list of schema names. If no schema is specified all schemas are used.',
-    #                         type=str, nargs='+', )
+    parser.add_argument('-s', '--database-schema',
+                            help='A list of schema names. If no schema is specified all schemas are used.',
+                            type=str, nargs='+', )
     parser.add_argument('-u', '--database-user',
                             help='The user for which the config will be created',
                             type=str, required=True )
@@ -51,6 +51,10 @@ def main():
                         )
 
     args = parser.parse_args(args=None if sys.argv[1:] else ['--help'])
+
+    schemas = args.database_schema
+    if schemas:
+        schemas = set(schemas[0].split(',') if ',' in schemas[0] else schemas)
     for_user = args.database_user
     config_file = args.out_cfg_file
     skip_function_sources = args.skip_function_sources
@@ -87,6 +91,7 @@ def main():
     schemas_config = asyncio.run(config.create_config_dict(
         dsn=dsn,
         for_user=for_user,
+        schemas=schemas,
         skip_function_sources=skip_function_sources
     ))
 
